# XspecT
:::{toctree}
:hidden:

quickstart
installation
input_data
cli
web
:::

:::{image} img/logo.png
:::

:::{include} ../README.md
:start-after: <!-- start intro -->
:end-before: <!-- end intro -->
:::


